domain

Attribute Macro domain 

#[domain]
Marks a type as part of the Domain layer (Layer 1)

Domain entities contain pure business logic with no infrastructure dependencies.

Example

#[domain]
struct User {
    id: UserId,
    email: Email,
}